@@ -3,14 +3,8 @@
 VERSION=$2
 TAR=../libcommons-lang3-java_$VERSION.orig.tar.gz
 DIR=libcommons-lang3-java-$VERSION
-TAG=$(echo "libcommons-lang3-java-$VERSION" | sed -re's/~(alpha|beta)/-\1-/')
+TAG=$(echo "LANG_$VERSION" | sed -re's/\./_/')
 
 svn export http://svn.apache.org/repos/asf/commons/proper/lang/tags/${TAG} $DIR
 GZIP=--best tar -c -z -f $TAR --exclude '*.jar' --exclude '*.class' $DIR
 rm -rf $DIR ../$TAG
-
-# move to directory 'tarballs'
-if [ -r .svn/deb-layout ]; then
-  . .svn/deb-layout
-  mv $TAR $origDir && echo "moved $TAR to $origDir"
-fi
